annotations.precomputed
=======================

.. automodule:: ngsidekick.annotations.precomputed
   :members:
   :undoc-members:
   :show-inheritance:

Precomputed Annotations
-----------------------

This module provides tools for working with precomputed annotation formats.

